@@ -2,19 +2,14 @@ import ast
 import logging
 
 
-logger = logging.getLogger()
-logger.debug(f'this')
-
-class FoundFSTringException(Exception):
-    pass
-
-def parse(script: str):
+def parse(filename: str, contents: str):
     """
     Parses a python file and identifies logger.info/debug/warning/error/fatal
     statements and if they contain an f-string it raises FoundFSTringException
     """
-    parsed = ast.parse(script)
+    parsed = ast.parse(contents)
     log_calls = []
+    warnings = []
     for node in ast.walk(parsed):
         if isinstance(node, ast.Expr):
             for child in ast.iter_child_nodes(node):
@@ -27,6 +22,5 @@ def parse(script: str):
                         log_calls.append(child)
     for log_call in log_calls:
         if isinstance(log_call.args[0], ast.JoinedStr):
-            raise FoundFSTringException
-
-    return 0
+            warnings.append((filename, log_call.lineno))
+    return warnings
